import request from '@/config/axios'

// 大模型调度建议 VO
export interface ScheduleSuggestVO {
  id: number // id
  modelId: number // 模型id
  conversationId: number // 会话id
  messageId: number // 消息id
  content: string // 调度建议
  status: number // 状态（0-未处理 1-已采纳 2-已忽略）
  createTime: Date // 创建时间
}

// 大模型调度建议 API
export const ScheduleSuggestApi = {
  // 查询大模型调度建议分页
  getScheduleSuggestPage: async (params: any) => {
    return await request.get({ url: `/ai/schedule-suggest/page`, params })
  },

  // 查询大模型调度建议详情
  getScheduleSuggest: async (id: number) => {
    return await request.get({ url: `/ai/schedule-suggest/get?id=` + id })
  },

  // 查询大模型调度建议详情
  getTopScheduleSuggests: async (top: number) => {
    return await request.get({ url: `/ai/schedule-suggest/simple-list?top=` + top })
  },

  // 新增大模型调度建议
  createScheduleSuggest: async (data: ScheduleSuggestVO) => {
    return await request.post({ url: `/ai/schedule-suggest/create`, data })
  },

  // 修改大模型调度建议
  updateScheduleSuggest: async (data: ScheduleSuggestVO) => {
    return await request.put({ url: `/ai/schedule-suggest/update`, data })
  },

  // 采纳忽略取消采纳
  operateScheduleSuggest: async (data: ScheduleSuggestVO) => {
    return await request.put({ url: `/ai/schedule-suggest/operate-suggest`, data})
  },

  // 删除大模型调度建议
  deleteScheduleSuggest: async (id: number) => {
    return await request.delete({ url: `/ai/schedule-suggest/delete?id=` + id })
  },

  // 导出大模型调度建议 Excel
  exportScheduleSuggest: async (params) => {
    return await request.download({ url: `/ai/schedule-suggest/export-excel`, params })
  },
}
